#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the Kylberg Texture dataset."""

from tensorbay.opendataset.KylbergTexture.loader import KylbergTexture

__all__ = ["KylbergTexture"]
